@@ -113,7 +113,7 @@ class Esmerald(Starlette):
         license: Optional[License] = None,
         security: Optional[List[SecurityRequirement]] = None,
         servers: List[Server] = [Server(url="/")],
-        secret: Optional[str] = settings.secret,
+        secret_key: Optional[str] = settings.secret_key,
         allowed_hosts: Optional[List[str]] = settings.allowed_hosts,
         allow_origins: Optional[List[str]] = settings.allow_origins,
         permissions: Optional[List["Permission"]] = settings.permissions,
@@ -164,7 +164,7 @@ class Esmerald(Starlette):
         self.terms_of_service = terms_of_service
         self.license_info = license
         self.servers = servers
-        self.secret = secret
+        self.secret_key = secret_key
         self.allowed_hosts = allowed_hosts
         self.allow_origins = allow_origins
         self.dependencies = dependencies or {}
@@ -233,6 +233,9 @@ class Esmerald(Starlette):
                 configurations=self.scheduler_configurations,
             )
 
+        self.activate_openapi()
+
+    def activate_openapi(self) -> None:
         if self.openapi_config and self.enable_openapi:
             self.openapi_schema = self.openapi_config.create_openapi_schema_model(self)
             gateway = gateways.Gateway(handler=self.openapi_config.openapi_apiview)
@@ -263,7 +266,7 @@ class Esmerald(Starlette):
         include_in_schema: bool = True,
     ) -> None:
         router = router or self.router
-        return router.add_route(
+        route = router.add_route(
             path=path,
             handler=handler,
             dependencies=dependencies,
@@ -274,6 +277,9 @@ class Esmerald(Starlette):
             include_in_schema=include_in_schema,
         )
 
+        self.activate_openapi()
+        return route
+
     def add_websocket_route(
         self,
         path: str,
@@ -324,9 +330,9 @@ class Esmerald(Starlette):
             )
 
             if self.on_startup:
-                self.on_startup.append(router.on_startup)
+                self.on_startup.extend(router.on_startup)
             if self.on_shutdown:
-                self.on_shutdown.append(router.on_shutdown)
+                self.on_shutdown.extend(router.on_shutdown)
 
             self.router.routes.append(
                 gateway(
@@ -338,9 +344,12 @@ class Esmerald(Starlette):
                     permissions=route.permissions,
                     handler=route.handler,
                     parent=self.router,
+                    is_from_router=True,
                 )
             )
 
+        self.activate_openapi()
+
     def get_default_exception_handlers(self) -> None:
         """
         Default exception handlers added to the application.
